package repositories;

import sk.upjs.jpaz2.AudioClip;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * Provides methods for saving and loading audio files. The class is designed as a singleton.
 */
public class AudioRepository
{
    /**
     * The instance of the repository.
     */
    private static AudioRepository instance;

    /**
     * The mapping of the loaded resource audios to its audio clips.
     */
    private final Map<String, AudioClip> loadedAudios;

    /**
     * Constructs the audio repository.
     */
    private AudioRepository()
    {
        loadedAudios = new HashMap<>();
    }

    /**
     * Gets the audio clip from the resource file name, stored in the package {@link resAudio}.
     */
    public AudioClip getAudio(String resourceName)
    {
        if (loadedAudios.containsKey(resourceName))
            return loadedAudios.get(resourceName);

        throw new RuntimeException("Couldn't get the resource: " + resourceName);
    }

    /**
     * Loads all audios to the memory.
     */
    public void loadAudio()
    {
        try
        {
            IOUtilities.executeForAllFilesInResourceFolder("resAudio", name ->
            {
                try
                {
                    AudioClip img = new AudioClip("resAudio", name);
                    loadedAudios.put(name, img);
                }
                catch (Exception e)
                {
                    System.err.println("Couldn't load the audio " + name);
                }
            });
        }
        catch (IOException e)
        {
            System.err.println(e.getMessage());
            e.printStackTrace();
        }
    }

    /**
     * Gets the instance of the repository.
     */
    public static AudioRepository getInstance()
    {
        if (instance == null)
            instance = new AudioRepository();

        return instance;
    }
}