package repositories;

import java.util.Scanner;

/**
 * Stores the game stats and provides methods for getting and parsing them from the format designed for storing in a
 * text file.
 */
class GameStatistics
{
    /**
     * The number of played games.
     */
    private int gamesPlayed;

    /**
     * The number of won games.
     */
    private int gamesWon;

    /**
     * The total points in all games.
     */
    private int totalPoints;

    /**
     * The number of played rounds in all games.
     */
    private int totalRounds;

    /**
     * The number of moonshots in all games.
     */
    private int moonshots;

    /**
     * Construct a new stats object from the given stats.
     *
     * @param gamesPlayed The number of games played.
     * @param gamesWon    The number of games won.
     * @param totalPoints The number of total points.
     * @param totalRounds The number of total rounds.
     * @param moonshots   The number of moonshots.
     */
    private GameStatistics(int gamesPlayed, int gamesWon, int totalPoints, int totalRounds, int moonshots)
    {
        this.gamesPlayed = gamesPlayed;
        this.gamesWon = gamesWon;
        this.totalPoints = totalPoints;
        this.totalRounds = totalRounds;
        this.moonshots = moonshots;
    }

    /**
     * Gets an empty stats object.
     */
    static GameStatistics getEmptyStats()
    {
        return new GameStatistics(0, 0, 0, 0, 0);
    }

    /**
     * Gets an instance of the game stats object from the string.
     */
    static GameStatistics getInstanceFromString(String string)
    {
        try (Scanner sc = new Scanner(string))
        {
            sc.useDelimiter("\t");
            return new GameStatistics(sc.nextInt(), sc.nextInt(), sc.nextInt(), sc.nextInt(), sc.nextInt());
        }
        catch (RuntimeException e)
        {
            throw new IllegalArgumentException("Error parsing game stats from the string: " + string);
        }
    }

    /**
     * Gets a string representation of the stats object.
     */
    @Override
    public String toString()
    {
        return gamesPlayed + "\t" + gamesWon + "\t" + totalPoints + "\t" + totalRounds + "\t" + moonshots;
    }

    /**
     * Gets number of played games.
     */
    int getGamesPlayed()
    {
        return gamesPlayed;
    }

    /**
     * Gets the number of won games.
     */
    int getGamesWon()
    {
        return gamesWon;
    }

    /**
     * Gets the number of total points.
     */
    int getTotalPoints()
    {
        return totalPoints;
    }

    /**
     * Gets the number of total rounds.
     */
    int getTotalRounds()
    {
        return totalRounds;
    }

    /**
     * Gets the number of moonshots.
     */
    int getMoonshots()
    {
        return moonshots;
    }

    /**
     * Sets the number of played games.
     */
    void setGamesPlayed(int gamesPlayed)
    {
        this.gamesPlayed = gamesPlayed;
    }

    /**
     * Sets the number of won games.
     */
    void setGamesWon(int gamesWon)
    {
        this.gamesWon = gamesWon;
    }

    /**
     * Sets the number of total points.
     */
    void setTotalPoints(int totalPoints)
    {
        this.totalPoints = totalPoints;
    }

    /**
     * Sets the number of total rounds.
     */
    void setTotalRounds(int totalRounds)
    {
        this.totalRounds = totalRounds;
    }

    /**
     * Sets the number of moonshots.
     */
    void setMoonshots(int moonshots)
    {
        this.moonshots = moonshots;
    }
}