package repositories;

import userInterface.Hearts;

import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.nio.file.*;
import java.util.Collections;
import java.util.Iterator;
import java.util.function.Consumer;
import java.util.stream.Stream;

/**
 * Provides utilities for input and output handling.
 */
class IOUtilities
{
    /**
     * Private constructor forbidding creation of class instances.
     */
    private IOUtilities()
    {
    }

    /**
     * Executes the given action for each file stored in the given resource folder. It works from an IDE and from a jar
     * file as well.
     */
    static void executeForAllFilesInResourceFolder(String folder, Consumer<String> action) throws IOException
    {
        // The code was found on the internet and it somehow works...

        Path myPath;
        FileSystem fileSystem = null;
        Stream<Path> paths;

        try
        {
            String folderPath = "/" + folder;
            URI uri;

            try
            {
                uri = Hearts.class.getResource(folderPath).toURI();
            }
            catch (URISyntaxException e)
            {
                throw new IOException(e);
            }

            if (uri.getScheme().equals("jar"))
            {
                fileSystem = FileSystems.newFileSystem(uri, Collections.emptyMap());
                myPath = fileSystem.getPath(folderPath);
            }
            else
                myPath = Paths.get(uri);

            paths = Files.walk(myPath, 1);

            for (Iterator<Path> it = paths.iterator(); it.hasNext(); )
            {
                Path path = it.next();

                if (!path.endsWith(folder))
                    action.accept(path.getFileName().toString());
            }

            paths.close();

            if (fileSystem != null)
                fileSystem.close();
        }
        catch (IOException e)
        {
            System.err.println("Couldn't execute the action for all resources in: " + folder);
            throw e;
        }
    }

    /**
     * Creates a file with the given name in the local application data folder of the OS and returns the folder file.
     * The method should work with Windows and Linux at least.
     */
    static File getAndCreateFileInLocalAppFolder(String fileName) throws IOException
    {
        String OS = (System.getProperty("os.name")).toUpperCase();
        String workingDirectory;

        if (OS.contains("WIN"))
            workingDirectory = System.getenv("AppData");
        else
            workingDirectory = System.getProperty("user.home") + "/Library/Application Support";

        File result = new File(workingDirectory + "/Hearts/" + fileName);
        File parent = result.getParentFile();

        if (!parent.exists() && !parent.mkdirs())
        {
            throw new IOException("Couldn't create dir: " + parent);
        }

        if (!result.exists() && !result.createNewFile())
        {
            throw new IOException("Couldn't create file: " + result);
        }

        return result;
    }
}