package userInterface;

import repositories.AudioRepository;
import repositories.GameRepository;
import repositories.ImageRepository;
import sk.upjs.jpaz2.JPAZWindow;
import sk.upjs.jpaz2.TransitionEffect;
import userInterface.utilities.SplashFrame;

/**
 * The class where the game starts. The class is designed as a singleton.
 */
public class Hearts
{
    /**
     * The instance of the game.
     */
    private static Hearts instance;

    /**
     * The main window of the game.
     */
    private JPAZWindow mainWindow;

    /**
     * The current screen which is being displayed.
     */
    private Screen currentScreen;

    /**
     * Indicates whether the background music is on.
     */
    private boolean isMusicOn;

    /**
     * Starts the game.
     */
    private void startGame()
    {
        isMusicOn = GameRepository.getInstance().getMusicState();
        currentScreen = IntroScreen.getInstance();

        mainWindow = new JPAZWindow(currentScreen);
        mainWindow.setIconImage(ImageRepository.getInstance().getImageShape("icon.png"));
        mainWindow.setTitle("Hearts");

        if (isMusicOn)
            currentScreen.turnOnMusic();
    }

    /**
     * Changes the current screen to the given one.
     *
     * @param screen      The screen to be displayed.
     * @param reloadMusic true, if we want to reload the screen's music, false otherwise
     */
    void changeScreen(Screen screen, boolean reloadMusic)
    {
        currentScreen = screen;
        mainWindow.rebindWithEffect(screen, TransitionEffect.FADE_OUT_BLACK_FADE_IN, 1000);

        if (reloadMusic)
            screen.turnOnMusic();

        screen.updateMusicButton();
    }

    /**
     * Gets whether the music is currently on.
     */
    public boolean isMusicOn()
    {
        return isMusicOn;
    }

    /**
     * Turns the music off / on and saves this state to the corresponding file.
     */
    public void setMusicOn(boolean isMusicOn)
    {
        this.isMusicOn = isMusicOn;
        GameRepository.getInstance().saveMusicState(isMusicOn);
    }

    /**
     * Gets the current screen.
     */
    public Screen getCurrentScreen()
    {
        return currentScreen;
    }

    /**
     * Gets the instance of the class.
     */
    public static Hearts getInstance()
    {
        if (instance == null)
            instance = new Hearts();

        return instance;
    }

    /**
     * The main method where the game starts.
     */
    public static void main(String[] args)
    {
        // We shall load all the resources into the memory in the very beginning in order to speed up our application.

        SplashFrame.showSplash("Hearts");
        ImageRepository.getInstance().loadAllImages();
        AudioRepository.getInstance().loadAudio();
        SplashFrame.hideSplash();
        Hearts.getInstance().startGame();
    }
}