package userInterface;

import repositories.AudioRepository;
import sk.upjs.jpaz2.AudioClip;
import sk.upjs.jpaz2.Pane;
import userInterface.panes.MusicOnOffIcon;

/**
 * An abstract pane, which represent a screen, where other pane objects will be displayed.
 */
public abstract class Screen extends Pane
{
    /**
     * The MusicOnOffIcon icon
     */
    private MusicOnOffIcon musicOnOffIcon;

    /**
     * Draws the music icon to the screen.
     */
    void drawMusicIcon()
    {
        musicOnOffIcon = new MusicOnOffIcon();
        musicOnOffIcon.drawToScreen(this);
    }

    /**
     * Gets the screen music.
     */
    public abstract AudioClip getScreenMusic();

    /**
     * Turns the screen music off.
     */
    void turnOffMusic()
    {
        getScreenMusic().stop();
    }

    /**
     * If game music is on, starts playing the screen music in a loop.
     */
    void turnOnMusic()
    {
        if (Hearts.getInstance().isMusicOn())
            getScreenMusic().playInLoop();
    }

    /**
     * Updates the view of the music button.
     */
    void updateMusicButton()
    {
        musicOnOffIcon.updateView();
    }

    /**
     * Plays a sound of the given name, if game music is on.
     *
     * @param soundName The name of the song, from the folder {@link resAudio}.
     */
    void playSound(String soundName)
    {
        Hearts game = Hearts.getInstance();

        // We check if game music is on and if this screen is the current one (i.e. it hasn't been changed)
        if (game.isMusicOn() && game.getCurrentScreen().equals(this))
            AudioRepository.getInstance().getAudio(soundName).playAsActionSound();
    }
}