package userInterface.panes;

import sk.upjs.jpaz2.ImageShape;
import sk.upjs.jpaz2.Pane;
import userInterface.utilities.PaneUtilities;

/**
 * A pane, which represents a simple rectangle-shaped button.
 */
public class Button extends Pane
{
    /**
     * The background of the button.
     */
    protected final ImageShape background;

    /**
     * The label of the button.
     */
    private final Label label;

    /**
     * Constructs a button with the given background and the given label.
     */
    public Button(ImageShape background, Label label)
    {
        super(background.getWidth(), background.getHeight());
        this.label = label;
        this.background = background;
        drawBackground();
        drawLabel();
    }

    /**
     * Draws the background to the button.
     */
    void drawBackground()
    {
        setTransparentBackground(true);
        PaneUtilities.drawBackground(this, background);
    }

    /**
     * Draws the label to the button.
     */
    private void drawLabel()
    {
        add(label);
        // we center our label
        double x = (double) (getWidth() - label.getWidth()) / 2;
        // -1 in the y-cord is there just for a better look
        double y = (double) (getHeight() - label.getHeight()) / 2 - 1;
        label.setPosition(x, y);
    }
}