package userInterface.panes;

import sk.upjs.jpaz2.Pane;
import sk.upjs.jpaz2.Turtle;

import java.awt.*;

/**
 * A pane, which represents a label with a centered given text with a given font and a given font color. It is meant to
 * be immutable, i.e. if you want to change the text, you'll need to create a new label.
 */
public class Label extends Pane
{
    /**
     * The label's text.
     */
    private final String text;

    /**
     * The label's text font.
     */
    private final Font font;

    /**
     * The label's font color.
     */
    private final Color color;

    /**
     * Constructs a label with the given text, font and font color.
     */
    public Label(String text, Font font, Color color)
    {
        this.text = text;
        this.font = font;
        this.color = color;
        drawLabel();
    }

    /**
     * Draws the label.
     */
    private void drawLabel()
    {
        setBorderWidth(0);
        setTransparentBackground(true);

        Turtle painter = new Turtle();
        add(painter);
        painter.setFont(font);
        painter.setPenColor(color);

        // Calculating of the pane height and the position of the painter might seem confusing.
        // I don't know why it works, but the getTextHeight() method definitely seems buggy.
        // I would expect that setting height to the painter.getTextHeight() and
        // position to the getHeight()/2.0 would work, but it would not.

        setWidth(painter.textWidth(text));
        setHeight(painter.getTextHeight() / 2 + 10);

        painter.setDirection(90);
        painter.setPosition(0, getHeight() - 5);
        painter.print(text);
        remove(painter);
    }
}