package userInterface.panes;

import repositories.ImageRepository;
import sk.upjs.jpaz2.AudioClip;
import sk.upjs.jpaz2.ImageShape;
import sk.upjs.jpaz2.Pane;
import sk.upjs.jpaz2.Turtle;
import userInterface.Hearts;
import userInterface.Screen;

import java.awt.event.MouseEvent;

/**
 * A pane, which represents a music on-off icon. The icon has two states, the music on state and the music off state. It
 * will automatically update its state when it's clicked on it.
 */
public class MusicOnOffIcon extends Pane
{
    /**
     * The turtle which graphically represents the icon. It has both views inside.
     */
    private Turtle button;

    /**
     * Constructs a music on-off icon.
     */
    public MusicOnOffIcon()
    {
        drawIcon();
    }

    /**
     * Draws the icon.
     */
    private void drawIcon()
    {
        setBorderWidth(0);
        setTransparentBackground(true);
        ImageShape shape = ImageRepository.getInstance().getImageShape("musicOnOff.png");
        resize(shape.getWidth(), shape.getHeight());
        button = new Turtle();
        button.setShape(shape);
        add(button);
        button.center();
    }

    /**
     * Draws the icon to the given screen. It automatically finds out the current music state.
     */
    public void drawToScreen(Screen screen)
    {
        screen.add(this);
        setPosition(screen.getWidth() - 10 - getWidth(), 10);
        updateView();
    }

    /**
     * Updates the view of the button. It automatically finds out the current music state.
     */
    public void updateView()
    {
        int view = Hearts.getInstance().isMusicOn() ? 0 : 1;
        button.setViewIndex(view);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void onMouseClicked(int x, int y, MouseEvent detail)
    {
        AudioClip music = Hearts.getInstance().getCurrentScreen().getScreenMusic();

        if (Hearts.getInstance().isMusicOn())
        {
            music.stop();
            Hearts.getInstance().setMusicOn(false);
        }
        else
        {
            music.playInLoop();
            Hearts.getInstance().setMusicOn(true);
        }

        updateView();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected boolean onCanClick(int x, int y)
    {
        return true;
    }
}