package userInterface.panes;

import sk.upjs.jpaz2.Pane;
import sk.upjs.jpaz2.TickTimer;

import java.awt.geom.Point2D;

/**
 * Represents a class which is used for animating panes. It can move a pane from it's starting position to the given
 * position, for the given time. The moving speed is constant (i.e. it's an uniform motion). It's an instance of {@link
 * TickTimer}.
 */
public class PaneAnimator extends TickTimer
{
    /**
     * The moving speed, in milliseconds. Also the period of the timer.
     */
    private static final int MOVING_SPEED = 24;

    /**
     * A pane to be moved.
     */
    private Pane movingPane;

    /**
     * A translation of the X-cord along the line from a start to an end position.
     */
    private double moveX;

    /**
     * A translation of the Y-cord along the line from a start to an end position.
     */
    private double moveY;

    /**
     * The maximum number of ticks of the timer. In each tick a pane moves along the line given by the start and the end
     * position.
     */
    private int maximumTicks = 0;

    /**
     * The current number of the ticks of the timer.
     */
    private int currentTicks = 0;

    /**
     * Animates the motion of the pane.
     *
     * @param end      The position when we want the pane to end up.
     * @param duration The duration that we want the motion to take, in milliseconds.
     */
    public void moveTo(Pane movingPane, Point2D end, int duration)
    {
        this.movingPane = movingPane;
        maximumTicks = duration / MOVING_SPEED;
        moveX = (end.getX() - movingPane.getPosition().getX()) / maximumTicks;
        moveY = (end.getY() - movingPane.getPosition().getY()) / maximumTicks;
        setTickPeriod(MOVING_SPEED);
        setEnabled(true);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void onTick()
    {
        // it simply translates the object by computed moveX and moveY
        movingPane.setPosition(movingPane.getX() + moveX, movingPane.getY() + moveY);
        currentTicks++;

        // if the move is finished, we'll turn the timer off
        if (currentTicks == maximumTicks)
            setEnabled(false);
    }
}