package userInterface.panes;

import sk.upjs.jpaz2.Pane;

import java.awt.*;

/**
 * An abstract pane, which provides a method for shading itself, i.e. adding a transparent black rectangle on the top of
 * this pane.
 */
public abstract class PaneWithShadow extends Pane
{
    /**
     * The pane representing the shadow.
     */
    private Pane shadow;

    /**
     * Indicates whether the pane has been shaded.
     */
    private boolean shaded;

    /**
     * Adds the shadow to the pane of the given transparency.
     *
     * @param value The number in the interval [0,1], where the higher value means the lighter pane.
     */
    public void shade(float value)
    {
        shadow = new Pane(getWidth(), getHeight());
        add(shadow);
        shadow.setBorderWidth(0);
        shadow.setBackgroundColor(Color.black);
        shadow.setTransparency(value);
        shaded = true;
    }

    /**
     * Removes the shade from the pane.
     */
    public void light()
    {
        remove(shadow);
        shadow.setTransparency(1);
        shaded = false;
    }

    /**
     * Gets if the pane is shaded.
     */
    public boolean isShaded()
    {
        return shaded;
    }
}