package userInterface.utilities;

import repositories.ImageRepository;
import sk.upjs.jpaz2.ImageShape;
import sk.upjs.jpaz2.Pane;
import sk.upjs.jpaz2.Turtle;

/**
 * Provides utilities for panes.
 */
public class PaneUtilities
{
    /**
     * Private constructor forbidding creation of class instances.
     */
    private PaneUtilities()
    {
    }

    /**
     * Draws the given background, in the form of an image resource name, to the given pane.
     */
    public static void drawBackground(Pane pane, String imageResourceName)
    {
        ImageShape shape = ImageRepository.getInstance().getImageShape(imageResourceName);
        drawBackground(pane, shape);
    }

    /**
     * Draws the given background, in the form of an ImageShape, to the given pane.
     */
    public static void drawBackground(Pane pane, ImageShape shape)
    {
        pane.setBorderWidth(0);
        pane.resize(shape.getWidth(), shape.getHeight());
        Turtle painter = new Turtle();
        painter.setShape(shape);
        pane.add(painter);
        painter.center();
        painter.stamp();
        pane.remove(painter);
    }

    /**
     * Returns whether the given parent pane contains the given child pane.
     */
    public static boolean contains(Pane parent, Pane child)
    {
        for (Pane pane : parent.getPanes())
            if (pane.equals(child))
                return true;

        return false;
    }
}