package userInterface.utilities;

import javax.swing.*;
import javax.swing.border.EmptyBorder;
import javax.swing.border.LineBorder;
import java.awt.*;

@SuppressWarnings("serial")
/**
 * The class provides methods for showing and hiding a splash frame.
 */
public class SplashFrame extends JFrame
{
    /**
     * The instance of the splash screen.
     */
    private static SplashFrame splashInstance;

    /**
     * Label with the splash text.
     */
    private JLabel lblInfo;

    /**
     * Create the frame.
     */
    private SplashFrame()
    {
        initializeComponents();
    }

    /**
     * Creates and initializes GUI components.
     */
    private void initializeComponents()
    {
        setBackground(Color.WHITE);
        setUndecorated(true);
        setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
        setBounds(100, 100, 296, 56);

        JPanel contentPane = new JPanel();
        contentPane.setBackground(Color.WHITE);
        contentPane.setBorder(new LineBorder(new Color(0, 0, 0)));
        setContentPane(contentPane);
        contentPane.setLayout(new BorderLayout(0, 0));

        lblInfo = new JLabel();
        lblInfo.setFont(new Font("Tahoma", Font.BOLD, 14));
        lblInfo.setHorizontalAlignment(SwingConstants.CENTER);
        contentPane.add(lblInfo, BorderLayout.CENTER);

        JProgressBar progressBar = new JProgressBar();
        progressBar.setBorder(new EmptyBorder(0, 5, 5, 5));
        progressBar.setIndeterminate(true);
        contentPane.add(progressBar, BorderLayout.SOUTH);
    }

    /**
     * Displays the splash frame.
     */
    public static void showSplash(String info)
    {
        EventQueue.invokeLater(() ->
        {
            try
            {
                if (splashInstance == null)
                {
                    splashInstance = new SplashFrame();
                    splashInstance.setLocationRelativeTo(null);
                }

                splashInstance.lblInfo.setText(info);
                splashInstance.setVisible(true);
            }
            catch (Exception e)
            {
                e.printStackTrace();
            }
        });
    }

    /**
     * Hides the splash frame.
     */
    public static void hideSplash()
    {
        EventQueue.invokeLater(() ->
        {
            try
            {
                if (splashInstance == null)
                    return;

                splashInstance.setVisible(false);
                splashInstance = null;
            }
            catch (Exception e)
            {
                e.printStackTrace();
            }
        });
    }
}
